==> ne_1.19.orig.tar.gz: ne-1.19/src/help.h <==
/* Help string externs.

	Copyright (C) 1993-1998 Sebastiano Vigna 
	Copyright (C) 1999-2001 Todd M. Lewis and Sebastiano Vigna

	This file is part of ne, the nice editor.

	This program is free software; you can redistribute it and/or modify it
	under the terms of the GNU General Public License as published by the
	Free Software Foundation; either version 2, or (at your option) any
	later version.
	
	This program is distributed in the hope that it will be useful, but
	WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
	General Public License for more details.
	
	You should have received a copy of the GNU General Public License along
	with this program; see the file COPYING.  If not, write to the Free
	Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
	02111-1307, USA.  */


extern const char * const ABOUT_HELP[ 5 ];
extern const char * const ADJUSTVIEW_HELP[ 20 ];
extern const char * const AUTOINDENT_HELP[ 43 ];
extern const char * const AUTOPREFS_HELP[ 14 ];
extern const char * const BACKSPACE_HELP[ 6 ];
extern const char * const BEEP_HELP[ 6 ];
extern const char * const BINARY_HELP[ 22 ];
extern const char * const CAPITALIZE_HELP[ 6 ];
extern const char * const CASESEARCH_HELP[ 12 ];
extern const char * const CENTER_HELP[ 8 ];
extern const char * const CLEAR_HELP[ 7 ];
extern const char * const CLIPNUMBER_HELP[ 11 ];
extern const char * const CLOSEDOC_HELP[ 7 ];
extern const char * const COPY_HELP[ 10 ];
extern const char * const CRLF_HELP[ 16 ];
extern const char * const CUT_HELP[ 5 ];
extern const char * const DELETECHAR_HELP[ 10 ];
extern const char * const DELETEEOL_HELP[ 10 ];
extern const char * const DELETELINE_HELP[ 9 ];
extern const char * const DOUNDO_HELP[ 20 ];
extern const char * const ERASE_HELP[ 6 ];
extern const char * const ESCAPE_HELP[ 7 ];
extern const char * const ESCAPETIME_HELP[ 14 ];
extern const char * const EXEC_HELP[ 13 ];
extern const char * const EXIT_HELP[ 6 ];
extern const char * const FASTGUI_HELP[ 15 ];
extern const char * const FIND_HELP[ 12 ];
extern const char * const FINDREGEXP_HELP[ 12 ];
extern const char * const FLAGS_HELP[ 25 ];
extern const char * const FLASH_HELP[ 6 ];
extern const char * const FREEFORM_HELP[ 18 ];
extern const char * const GOTOBOOKMARK_HELP[ 7 ];
extern const char * const GOTOCOLUMN_HELP[ 8 ];
extern const char * const GOTOLINE_HELP[ 10 ];
extern const char * const GOTOMARK_HELP[ 9 ];
extern const char * const HELP_HELP[ 15 ];
extern const char * const HEXCODE_HELP[ 7 ];
extern const char * const INSERT_HELP[ 12 ];
extern const char * const INSERTCHAR_HELP[ 20 ];
extern const char * const INSERTLINE_HELP[ 7 ];
extern const char * const INSERTSTRING_HELP[ 12 ];
extern const char * const LINEDOWN_HELP[ 6 ];
extern const char * const LINEUP_HELP[ 6 ];
extern const char * const LOADAUTOPREFS_HELP[ 7 ];
extern const char * const LOADPREFS_HELP[ 16 ];
extern const char * const MACRO_HELP[ 31 ];
extern const char * const MARK_HELP[ 14 ];
extern const char * const MARKVERT_HELP[ 10 ];
extern const char * const MATCHBRACKET_HELP[ 8 ];
extern const char * const MODIFIED_HELP[ 15 ];
extern const char * const MOVEBOS_HELP[ 6 ];
extern const char * const MOVEEOF_HELP[ 5 ];
extern const char * const MOVEEOL_HELP[ 5 ];
extern const char * const MOVEEOW_HELP[ 8 ];
extern const char * const MOVEINCDOWN_HELP[ 9 ];
extern const char * const MOVEINCUP_HELP[ 9 ];
extern const char * const MOVELEFT_HELP[ 6 ];
extern const char * const MOVERIGHT_HELP[ 6 ];
extern const char * const MOVESOF_HELP[ 5 ];
extern const char * const MOVESOL_HELP[ 6 ];
extern const char * const MOVETOS_HELP[ 5 ];
extern const char * const NEWDOC_HELP[ 8 ];
extern const char * const NEXTDOC_HELP[ 5 ];
extern const char * const NEXTPAGE_HELP[ 8 ];
extern const char * const NEXTWORD_HELP[ 6 ];
extern const char * const NOFILEREQ_HELP[ 10 ];
extern const char * const NOP_HELP[ 5 ];
extern const char * const OPEN_HELP[ 18 ];
extern const char * const OPENCLIP_HELP[ 14 ];
extern const char * const OPENMACRO_HELP[ 14 ];
extern const char * const OPENNEW_HELP[ 6 ];
extern const char * const PAGEDOWN_HELP[ 6 ];
extern const char * const PAGEUP_HELP[ 6 ];
extern const char * const PARAGRAPH_HELP[ 24 ];
extern const char * const PASTE_HELP[ 7 ];
extern const char * const PASTEVERT_HELP[ 7 ];
extern const char * const PLAY_HELP[ 15 ];
extern const char * const POPPREFS_HELP[ 24 ];
extern const char * const PRESERVECR_HELP[ 15 ];
extern const char * const PREVDOC_HELP[ 5 ];
extern const char * const PREVPAGE_HELP[ 8 ];
extern const char * const PREVWORD_HELP[ 8 ];
extern const char * const PUSHPREFS_HELP[ 24 ];
extern const char * const QUIT_HELP[ 6 ];
extern const char * const READONLY_HELP[ 13 ];
extern const char * const RECORD_HELP[ 21 ];
extern const char * const REDO_HELP[ 8 ];
extern const char * const REFRESH_HELP[ 11 ];
extern const char * const REPEATLAST_HELP[ 26 ];
extern const char * const REPLACE_HELP[ 46 ];
extern const char * const REPLACEALL_HELP[ 12 ];
extern const char * const REPLACEONCE_HELP[ 10 ];
extern const char * const RIGHTMARGIN_HELP[ 12 ];
extern const char * const SAVE_HELP[ 12 ];
extern const char * const SAVEAS_HELP[ 14 ];
extern const char * const SAVEAUTOPREFS_HELP[ 7 ];
extern const char * const SAVECLIP_HELP[ 13 ];
extern const char * const SAVEDEFPREFS_HELP[ 6 ];
extern const char * const SAVEMACRO_HELP[ 20 ];
extern const char * const SAVEPREFS_HELP[ 11 ];
extern const char * const SEARCHBACK_HELP[ 14 ];
extern const char * const SELECTDOC_HELP[ 14 ];
extern const char * const SETBOOKMARK_HELP[ 7 ];
extern const char * const STATUSBAR_HELP[ 19 ];
extern const char * const SUSPEND_HELP[ 6 ];
extern const char * const SYSTEM_HELP[ 10 ];
extern const char * const TABSIZE_HELP[ 9 ];
extern const char * const THROUGH_HELP[ 15 ];
extern const char * const TOGGLESEOF_HELP[ 10 ];
extern const char * const TOGGLESEOL_HELP[ 10 ];
extern const char * const TOLOWER_HELP[ 5 ];
extern const char * const TOUPPER_HELP[ 15 ];
extern const char * const TURBO_HELP[ 29 ];
extern const char * const UNDELLINE_HELP[ 15 ];
extern const char * const UNDO_HELP[ 9 ];
extern const char * const UNLOADMACROS_HELP[ 12 ];
extern const char * const VERBOSEMACROS_HELP[ 17 ];
extern const char * const WORDWRAP_HELP[ 12 ];

/* This file was automatically generated by info2src.pl. */

==> ne_1.33.orig.tar.gz: ne-1.33.orig/src/help.h <==
/* Help string externs.

	Copyright (C) 1993-1998 Sebastiano Vigna 
	Copyright (C) 1999-2004 Todd M. Lewis and Sebastiano Vigna

	This file is part of ne, the nice editor.

	This program is free software; you can redistribute it and/or modify it
	under the terms of the GNU General Public License as published by the
	Free Software Foundation; either version 2, or (at your option) any
	later version.
	
	This program is distributed in the hope that it will be useful, but
	WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
	General Public License for more details.
	
	You should have received a copy of the GNU General Public License along
	with this program; see the file COPYING.  If not, write to the Free
	Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
	02111-1307, USA.  */


extern const char * const ABOUT_HELP[ 5 ];
extern const char * const ADJUSTVIEW_HELP[ 20 ];
extern const char * const AUTOINDENT_HELP[ 22 ];
extern const char * const AUTOPREFS_HELP[ 14 ];
extern const char * const BACKSPACE_HELP[ 6 ];
extern const char * const BEEP_HELP[ 6 ];
extern const char * const BINARY_HELP[ 22 ];
extern const char * const CAPITALIZE_HELP[ 6 ];
extern const char * const CASESEARCH_HELP[ 12 ];
extern const char * const CENTER_HELP[ 8 ];
extern const char * const CLEAR_HELP[ 7 ];
extern const char * const CLIPNUMBER_HELP[ 11 ];
extern const char * const CLOSEDOC_HELP[ 7 ];
extern const char * const COPY_HELP[ 10 ];
extern const char * const CRLF_HELP[ 16 ];
extern const char * const CUT_HELP[ 5 ];
extern const char * const DELETECHAR_HELP[ 10 ];
extern const char * const DELETEEOL_HELP[ 10 ];
extern const char * const DELETELINE_HELP[ 9 ];
extern const char * const DOUNDO_HELP[ 20 ];
extern const char * const ERASE_HELP[ 6 ];
extern const char * const ESCAPE_HELP[ 7 ];
extern const char * const ESCAPETIME_HELP[ 16 ];
extern const char * const EXEC_HELP[ 13 ];
extern const char * const EXIT_HELP[ 6 ];
extern const char * const FASTGUI_HELP[ 15 ];
extern const char * const FIND_HELP[ 12 ];
extern const char * const FINDREGEXP_HELP[ 12 ];
extern const char * const FLAGS_HELP[ 27 ];
extern const char * const FLASH_HELP[ 6 ];
extern const char * const FREEFORM_HELP[ 18 ];
extern const char * const GOTOBOOKMARK_HELP[ 7 ];
extern const char * const GOTOCOLUMN_HELP[ 8 ];
extern const char * const GOTOLINE_HELP[ 10 ];
extern const char * const GOTOMARK_HELP[ 9 ];
extern const char * const HELP_HELP[ 15 ];
extern const char * const HEXCODE_HELP[ 7 ];
extern const char * const INSERT_HELP[ 12 ];
extern const char * const INSERTCHAR_HELP[ 20 ];
extern const char * const INSERTLINE_HELP[ 7 ];
extern const char * const INSERTSTRING_HELP[ 12 ];
extern const char * const LINEDOWN_HELP[ 6 ];
extern const char * const LINEUP_HELP[ 6 ];
extern const char * const LOADAUTOPREFS_HELP[ 7 ];
extern const char * const LOADPREFS_HELP[ 16 ];
extern const char * const MACRO_HELP[ 31 ];
extern const char * const MARK_HELP[ 14 ];
extern const char * const MARKVERT_HELP[ 10 ];
extern const char * const MATCHBRACKET_HELP[ 8 ];
extern const char * const MODIFIED_HELP[ 15 ];
extern const char * const MOVEBOS_HELP[ 6 ];
extern const char * const MOVEEOF_HELP[ 5 ];
extern const char * const MOVEEOL_HELP[ 5 ];
extern const char * const MOVEEOW_HELP[ 8 ];
extern const char * const MOVEINCDOWN_HELP[ 9 ];
extern const char * const MOVEINCUP_HELP[ 9 ];
extern const char * const MOVELEFT_HELP[ 6 ];
extern const char * const MOVERIGHT_HELP[ 6 ];
extern const char * const MOVESOF_HELP[ 5 ];
extern const char * const MOVESOL_HELP[ 6 ];
extern const char * const MOVETOS_HELP[ 5 ];
extern const char * const NEWDOC_HELP[ 8 ];
extern const char * const NEXTDOC_HELP[ 5 ];
extern const char * const NEXTPAGE_HELP[ 8 ];
extern const char * const NEXTWORD_HELP[ 6 ];
extern const char * const NOFILEREQ_HELP[ 10 ];
extern const char * const NOP_HELP[ 5 ];
extern const char * const OPEN_HELP[ 18 ];
extern const char * const OPENCLIP_HELP[ 14 ];
extern const char * const OPENMACRO_HELP[ 14 ];
extern const char * const OPENNEW_HELP[ 6 ];
extern const char * const PAGEDOWN_HELP[ 6 ];
extern const char * const PAGEUP_HELP[ 6 ];
extern const char * const PARAGRAPH_HELP[ 24 ];
extern const char * const PASTE_HELP[ 7 ];
extern const char * const PASTEVERT_HELP[ 7 ];
extern const char * const PLAY_HELP[ 15 ];
extern const char * const POPPREFS_HELP[ 24 ];
extern const char * const PRESERVECR_HELP[ 15 ];
extern const char * const PREVDOC_HELP[ 5 ];
extern const char * const PREVPAGE_HELP[ 8 ];
extern const char * const PREVWORD_HELP[ 8 ];
extern const char * const PUSHPREFS_HELP[ 24 ];
extern const char * const QUIT_HELP[ 6 ];
extern const char * const READONLY_HELP[ 13 ];
extern const char * const RECORD_HELP[ 21 ];
extern const char * const REDO_HELP[ 8 ];
extern const char * const REFRESH_HELP[ 11 ];
extern const char * const REPEATLAST_HELP[ 26 ];
extern const char * const REPLACE_HELP[ 46 ];
extern const char * const REPLACEALL_HELP[ 12 ];
extern const char * const REPLACEONCE_HELP[ 10 ];
extern const char * const RIGHTMARGIN_HELP[ 12 ];
extern const char * const SAVE_HELP[ 12 ];
extern const char * const SAVEAS_HELP[ 14 ];
extern const char * const SAVEAUTOPREFS_HELP[ 7 ];
extern const char * const SAVECLIP_HELP[ 13 ];
extern const char * const SAVEDEFPREFS_HELP[ 6 ];
extern const char * const SAVEMACRO_HELP[ 20 ];
extern const char * const SAVEPREFS_HELP[ 11 ];
extern const char * const SEARCHBACK_HELP[ 14 ];
extern const char * const SELECTDOC_HELP[ 14 ];
extern const char * const SETBOOKMARK_HELP[ 7 ];
extern const char * const STATUSBAR_HELP[ 19 ];
extern const char * const SUSPEND_HELP[ 6 ];
extern const char * const SYSTEM_HELP[ 10 ];
extern const char * const TABSIZE_HELP[ 9 ];
extern const char * const THROUGH_HELP[ 15 ];
extern const char * const TOGGLESEOF_HELP[ 10 ];
extern const char * const TOGGLESEOL_HELP[ 10 ];
extern const char * const TOLOWER_HELP[ 5 ];
extern const char * const TOUPPER_HELP[ 15 ];
extern const char * const TURBO_HELP[ 29 ];
extern const char * const UNDELLINE_HELP[ 15 ];
extern const char * const UNDO_HELP[ 9 ];
extern const char * const UNLOADMACROS_HELP[ 12 ];
extern const char * const UTF8_HELP[ 20 ];
extern const char * const UTF8AUTO_HELP[ 13 ];
extern const char * const UTF8IO_HELP[ 13 ];
extern const char * const VERBOSEMACROS_HELP[ 17 ];
extern const char * const WORDWRAP_HELP[ 12 ];

/* This file was automatically generated by info2src.pl. */
